class Tile:
    coordinates = []
    mine = False
    popped = False

    def __init__(self, coordinates: list, mine: bool = False):
        self.coordinates = coordinates
        self.mine = mine

    def __str__(self):
        if self.mine:
            return f'Mine: {self.coordinates}'
        return f'Tile: {self.coordinates}'

    def pop_tile(self):
        self.popped = True

    def calculate_tile_number(self, minefield):
        if not self.popped:
            return '#'
        if self.mine:
            return 'X'
        number_of_mines = 0
        tiles_to_find = [
            [self.coordinates[0]+1, self.coordinates[1]],
            [self.coordinates[0], self.coordinates[1]+1],
            [self.coordinates[0]+1, self.coordinates[1]+1],
            [self.coordinates[0]-1, self.coordinates[1]],
            [self.coordinates[0], self.coordinates[1]-1],
            [self.coordinates[0]-1, self.coordinates[1]-1],
            [self.coordinates[0]+1, self.coordinates[1]-1],
            [self.coordinates[0]-1, self.coordinates[1]+1]
        ]
        for tile in minefield.tiles:
            for i in range(len(tiles_to_find)):
                if tile.coordinates == tiles_to_find[i] and tile.mine:
                    number_of_mines += 1
                    break
        return number_of_mines



from .minefield import Minefield
from .sweeper import Sweeper


def main():
    minefield = Minefield(width=10, height=10, number_of_mines=10)

    minefield.generate_tiles()
    minefield.place_mines()

    sweeper = Sweeper(minefield)
    sweeper.main_menu()


if __name__ == "__main__":
    main()



from .minefield import Minefield
import os


class Sweeper:
    minefield = Minefield()

    def __init__(self, minefield):
        self.minefield = minefield

    # @staticmethod
    def sweep_tile(self, x_coordinate, y_coordinate):
        coordinates = [x_coordinate, y_coordinate]
        for tile in self.minefield.tiles:
            if coordinates == tile.coordinates:
                tile.pop_tile()
                if tile.mine:
                    print("Bang!")
                    self.game_over()
                    break
        os.system('clear')
        self.minefield.draw_minefield()
        self.get_user_coordinate_input()

    def restart(self):
        self.minefield = Minefield(width=10, height=10, number_of_mines=10)
        self.minefield.generate_tiles()
        self.minefield.place_mines()

    def game_over(self):
        os.system('clear')
        self.minefield.draw_minefield()
        print('Game over')
        input('Press [ENTER] to return to restart.')
        self.restart()
        os.system('clear')

    def main_menu(self):
        os.system('clear')
        print('Welcome to MineSweeper')
        input('Press [ENTER] to start.')
        os.system('clear')
        self.minefield.draw_minefield()
        self.get_user_coordinate_input()

    def get_user_coordinate_input(self):
        while True:
            try:
                coordinates = input('Input coordinates: ').split(' ')
                x_coordinate = int(coordinates[0])
                y_coordinate = int(coordinates[1])
                if len(coordinates) > 2:
                    raise ValueError
            except (ValueError, IndexError):
                print("Inputted coordinates are invalid, try again.")
                continue
            else:
                break
        self.sweep_tile(x_coordinate, y_coordinate)



from setuptools import setup

setup(
    name='pysweep',
    version='0.1.0',
    description='Simple minesweeper game for the terminal',
    long_description='Simple minesweeper game for the terminal',
    url='https://github.com/AnttiRae/PySweep',
    author='Antti rae',
    author_email='anttiraework@gmail.com',
    license='MIT',
    entry_points={'console_scripts': ['pysweep = pysweep.__main__:main', ]},

    classifiers=[
        'Programming Language :: Python :: 3',
    ],
)



from .tile import Tile
import random


class Minefield:
    width, height, number_of_mines = 5, 5, 5
    tiles = []

    def __init__(self, width=5, height=5, number_of_mines=5):
        self.width = width
        self.height = height
        self.number_of_mines = number_of_mines

    def generate_tiles(self):
        self.tiles = []
        for i in range(self.width):
            for j in range(self.height):
                self.tiles.append(Tile([i, j]))

    # place X amount of mines on field on random locations
    def place_mines(self):
        if len(self.tiles) == 0:
            return
        tiles_to_mine = random.sample(self.tiles, self.number_of_mines)
        for tile in tiles_to_mine:
            tile.mine = True

    def draw_minefield(self):
        for tile in self.tiles:
            if tile.coordinates[1] == self.width-1:
                print(f' {tile.calculate_tile_number(self)} ')
            else:
                print(f' {tile.calculate_tile_number(self)} ', end='')


